@@ -718,7 +718,10 @@ pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
+pref("network.IDN.whitelist.lu", true);
 pref("network.IDN.whitelist.no", true);
+pref("network.IDN.whitelist.nu", true);
+pref("network.IDN.whitelist.nz", true);
 pref("network.IDN.whitelist.pl", true);
 pref("network.IDN.whitelist.pr", true);
 pref("network.IDN.whitelist.se", true);
@@ -728,12 +731,21 @@ pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
-// non-ccTLDs
+// IDN ccTLDs
+// sa, Saudi Arabia, .<al-Saudiah>
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// jo, Jordan, .<Al-Ordon>
+pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+
+// gTLDs
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
 pref("network.IDN.whitelist.org", true);
+pref("network.IDN.whitelist.tel", true);
 
 // NOTE: Before these can be removed, one of bug 414812's tests must be updated
 //       or it will likely fail!  Please CC jwalden+bmo on the bug associated
@@ -813,7 +825,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 835 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 847 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -872,6 +884,9 @@ pref("network.proxy.autoconfig_url", "");
 pref("network.proxy.autoconfig_retry_interval_min", 5);    // 5 seconds
 pref("network.proxy.autoconfig_retry_interval_max", 300);  // 5 minutes
 
+pref("network.buffer.cache.count", 24);
+pref("network.buffer.cache.size",  4096);
+
 pref("converter.html2txt.structs",          true); // Output structured phrases (strong, em, code, sub, sup, b, i, u)
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
@@ -1233,15 +1248,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1652 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 1667 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2076 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2091 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2279 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2294 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2375 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2390 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2378 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2393 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1511,20 +1526,20 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2650 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2665 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2718 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2733 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2744 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2759 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2764 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2779 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2766 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2781 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2772 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2787 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1561,9 +1576,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2814 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2829 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2819 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2834 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
